==> haskell-parsers-0.12.10-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.10
id: parsers-0.12.10-H8p7mW3SwViEwkRCUjVdjW
key: parsers-0.12.10-H8p7mW3SwViEwkRCUjVdjW
license: BSD-3-Clause
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
abi: a913b09b9775e13e2c9b8b8c78188498
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
import-dirs: /usr/lib/ghc-8.6.5/site-local/parsers-0.12.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/parsers-0.12.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/parsers-0.12.10
hs-libraries: HSparsers-0.12.10-H8p7mW3SwViEwkRCUjVdjW
depends:
    attoparsec-0.13.2.3-G0AWAouFPeyAsmzjnpc0yX base-4.12.0.0
    base-orphans-0.8.1-ADx13UE5kNMLP8OA0gQSRH binary-0.8.6.0
    charset-0.3.7.1-BgKaI6TQhzNDRvB2SDayf8 containers-0.6.0.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-HXsxAsTvm9z649814xbQu4
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.10-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.10
id: parsers-0.12.10-FPg5oiObu8yFZNrwSw8L5c
key: parsers-0.12.10-FPg5oiObu8yFZNrwSw8L5c
license: BSD-3-Clause
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
abi: ba84b8216fa2dbf6124d3ed020f1f478
exposed: True
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
import-dirs: /usr/lib/ghc-8.6.5/site-local/parsers-0.12.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/parsers-0.12.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/parsers-0.12.10
hs-libraries: HSparsers-0.12.10-FPg5oiObu8yFZNrwSw8L5c
depends:
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3 binary-0.8.6.0
    charset-0.3.7.1-8ZrQ9egE3iI6eE18mlHOfc containers-0.6.0.1 mtl-2.2.2
    parsec-3.1.13.0 scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
